@@ -82,7 +82,7 @@ class EntitySet(object):
             df = dataframes[df_name][0]
             if df.ww.schema is not None and df.ww.name != df_name:
                 raise ValueError(
-                    f"Naming conflict in dataframes dictionary: dictionary key '{df_name}' does not match dataframe name '{df.ww.name}'"
+                    f"Naming conflict in dataframes dictionary: dictionary key '{df_name}' does not match dataframe name '{df.ww.name}'",
                 )
 
             index_column = None
@@ -299,7 +299,9 @@ class EntitySet(object):
         for df in self.dataframes:
             if df.shape:
                 repr_out += "\n    {} [Rows: {}, Columns: {}]".format(
-                    df.ww.name, df.shape[0], df.shape[1]
+                    df.ww.name,
+                    df.shape[0],
+                    df.shape[1],
                 )
             else:
                 repr_out += "\n    {} [Rows: None, Columns: None]".format(df.ww.name)
@@ -362,7 +364,7 @@ class EntitySet(object):
             or child_column_name
         ):
             raise ValueError(
-                "Cannot specify dataframe and column name values and also supply a Relationship"
+                "Cannot specify dataframe and column name values and also supply a Relationship",
             )
 
         if not relationship:
@@ -412,7 +414,7 @@ class EntitySet(object):
             warnings.warn(
                 f"Logical type {child_ltype} for child column {child_column} does not match "
                 f"parent column {parent_column} logical type {parent_ltype}. {difference_msg}"
-                "Changing child logical type to match parent."
+                "Changing child logical type to match parent.",
             )
             child_df.ww.set_types(logical_types={child_column: parent_ltype})
 
@@ -462,7 +464,7 @@ class EntitySet(object):
             :func:`BaseEntitySet.find_backward_paths`
         """
         for sub_dataframe_name, path in self._forward_dataframe_paths(
-            start_dataframe_name
+            start_dataframe_name,
         ):
             if sub_dataframe_name == goal_dataframe_name:
                 yield path
@@ -506,7 +508,8 @@ class EntitySet(object):
             # Copy seen dataframes for each next node to allow multiple paths (but
             # not cycles).
             descendants = self._forward_dataframe_paths(
-                next_dataframe, seen_dataframes.copy()
+                next_dataframe,
+                seen_dataframes.copy(),
             )
             for sub_dataframe_name, sub_path in descendants:
                 yield sub_dataframe_name, [relationship] + sub_path
@@ -528,7 +531,8 @@ class EntitySet(object):
 
             if deep:
                 sub_dataframes = self.get_forward_dataframes(
-                    parent_dataframe_name, deep=True
+                    parent_dataframe_name,
+                    deep=True,
                 )
                 for sub_dataframe_name, path in sub_dataframes:
                     yield sub_dataframe_name, direct_path + path
@@ -550,7 +554,8 @@ class EntitySet(object):
 
             if deep:
                 sub_dataframes = self.get_backward_dataframes(
-                    child_dataframe_name, deep=True
+                    child_dataframe_name,
+                    deep=True,
                 )
                 for sub_dataframe_name, path in sub_dataframes:
                     yield sub_dataframe_name, direct_path + path
@@ -674,7 +679,7 @@ class EntitySet(object):
                 raise ValueError(
                     "All dataframes must be of the same type. "
                     "Cannot add dataframe of type {} to an entityset with existing dataframes "
-                    "of type {}".format(type(dataframe), type(self.dataframes[0]))
+                    "of type {}".format(type(dataframe), type(self.dataframes[0])),
                 )
 
         # Only allow string column names
@@ -684,14 +689,14 @@ class EntitySet(object):
         if non_string_names:
             raise ValueError(
                 "All column names must be strings (Columns {} "
-                "are not strings)".format(non_string_names)
+                "are not strings)".format(non_string_names),
             )
 
         if dataframe.ww.schema is None:
             if dataframe_name is None:
                 raise ValueError(
                     "Cannot add dataframe to EntitySet without a name. "
-                    "Please provide a value for the dataframe_name parameter."
+                    "Please provide a value for the dataframe_name parameter.",
                 )
             # Warn when performing inference on Dask or Spark DataFrames
             if not set(dataframe.columns).issubset(set(logical_types.keys())) and (
@@ -700,11 +705,13 @@ class EntitySet(object):
             ):
                 warnings.warn(
                     "Performing type inference on Dask or Spark DataFrames may be computationally intensive. "
-                    "Specify logical types for each column to speed up EntitySet initialization."
+                    "Specify logical types for each column to speed up EntitySet initialization.",
                 )
 
             index_was_created, index, dataframe = _get_or_create_index(
-                index, make_index, dataframe
+                index,
+                make_index,
+                dataframe,
             )
 
             dataframe.ww.init(
@@ -721,11 +728,11 @@ class EntitySet(object):
         else:
             if dataframe.ww.name is None:
                 raise ValueError(
-                    "Cannot add a Woodwork DataFrame to EntitySet without a name"
+                    "Cannot add a Woodwork DataFrame to EntitySet without a name",
                 )
             if dataframe.ww.index is None:
                 raise ValueError(
-                    "Cannot add Woodwork DataFrame to EntitySet without index"
+                    "Cannot add Woodwork DataFrame to EntitySet without index",
                 )
 
             extra_params = []
@@ -746,7 +753,7 @@ class EntitySet(object):
             if extra_params:
                 warnings.warn(
                     "A Woodwork-initialized DataFrame was provided, so the following parameters were ignored: "
-                    + ", ".join(extra_params)
+                    + ", ".join(extra_params),
                 )
 
         if dataframe.ww.time_index is not None:
@@ -755,7 +762,8 @@ class EntitySet(object):
 
         if secondary_time_index:
             self._set_secondary_time_index(
-                dataframe, secondary_time_index=secondary_time_index
+                dataframe,
+                secondary_time_index=secondary_time_index,
             )
 
         dataframe = self._normalize_values(dataframe)
@@ -825,41 +833,43 @@ class EntitySet(object):
             if not isinstance(col_list, list):
                 raise TypeError(
                     "'{}' must be a list, but received type {}".format(
-                        list_name, type(col_list)
-                    )
+                        list_name,
+                        type(col_list),
+                    ),
                 )
             if len(col_list) != len(set(col_list)):
                 raise ValueError(
-                    f"'{list_name}' contains duplicate columns. All columns must be unique."
+                    f"'{list_name}' contains duplicate columns. All columns must be unique.",
                 )
             for col_name in col_list:
                 if col_name == index:
                     raise ValueError(
                         "Not adding {} as both index and column in {}".format(
-                            col_name, list_name
-                        )
+                            col_name,
+                            list_name,
+                        ),
                     )
 
         for col in additional_columns:
             if col == base_dataframe.ww.time_index:
                 raise ValueError(
                     "Not moving {} as it is the base time index column. Perhaps, move the column to the copy_columns.".format(
-                        col
-                    )
+                        col,
+                    ),
                 )
 
         if isinstance(make_time_index, str):
             if make_time_index not in base_dataframe.columns:
                 raise ValueError(
-                    "'make_time_index' must be a column in the base dataframe"
+                    "'make_time_index' must be a column in the base dataframe",
                 )
             elif make_time_index not in additional_columns + copy_columns:
                 raise ValueError(
-                    "'make_time_index' must be specified in 'additional_columns' or 'copy_columns'"
+                    "'make_time_index' must be specified in 'additional_columns' or 'copy_columns'",
                 )
         if index == base_dataframe.ww.index:
             raise ValueError(
-                "'index' must be different from the index column of the base dataframe"
+                "'index' must be different from the index column of the base dataframe",
             )
 
         transfer_types = {}
@@ -926,7 +936,7 @@ class EntitySet(object):
         if new_dataframe_time_index is not None and new_dataframe_time_index == index:
             raise ValueError(
                 "time_index and index cannot be the same value, %s"
-                % (new_dataframe_time_index)
+                % (new_dataframe_time_index),
             )
 
         selected_columns = (
@@ -942,7 +952,7 @@ class EntitySet(object):
 
         if make_time_index:
             new_dataframe2 = new_dataframe2.rename(
-                columns={base_time_index: new_dataframe_time_index}
+                columns={base_time_index: new_dataframe_time_index},
             )
         if make_secondary_time_index:
             assert (
@@ -951,14 +961,14 @@ class EntitySet(object):
             secondary_time_index = list(make_secondary_time_index.keys())[0]
 
             secondary_columns = [index, secondary_time_index] + list(
-                make_secondary_time_index.values()
+                make_secondary_time_index.values(),
             )[0]
             secondary_df = new_dataframe.drop_duplicates(index, keep="last")[
                 secondary_columns
             ]
             if new_dataframe_secondary_time_index:
                 secondary_df = secondary_df.rename(
-                    columns={secondary_time_index: new_dataframe_secondary_time_index}
+                    columns={secondary_time_index: new_dataframe_secondary_time_index},
                 )
                 secondary_time_index = new_dataframe_secondary_time_index
             else:
@@ -1002,7 +1012,8 @@ class EntitySet(object):
         )
 
         self.add_dataframe(
-            new_dataframe, secondary_time_index=make_secondary_time_index
+            new_dataframe,
+            secondary_time_index=make_secondary_time_index,
         )
 
         self.dataframe_dict[base_dataframe_name] = self.dataframe_dict[
@@ -1010,11 +1021,14 @@ class EntitySet(object):
         ].ww.drop(additional_columns)
 
         self.dataframe_dict[base_dataframe_name].ww.add_semantic_tags(
-            {base_dataframe_index: "foreign_key"}
+            {base_dataframe_index: "foreign_key"},
         )
 
         self.add_relationship(
-            new_dataframe_name, index, base_dataframe_name, base_dataframe_index
+            new_dataframe_name,
+            index,
+            base_dataframe_name,
+            base_dataframe_index,
         )
         self.reset_data_description()
         return self
@@ -1030,7 +1044,7 @@ class EntitySet(object):
         if not self.__eq__(other):
             raise ValueError(
                 "Entitysets must have the same dataframes, relationships"
-                ", and column names"
+                ", and column names",
             )
 
         if inplace:
@@ -1052,7 +1066,7 @@ class EntitySet(object):
             # If both DataFrames have made indexes, there will likely
             # be overlap in the index column, so we use the other values
             if self_df.ww.metadata.get("created_index") or other_df.ww.metadata.get(
-                "created_index"
+                "created_index",
             ):
                 columns = [
                     col
@@ -1194,7 +1208,9 @@ class EntitySet(object):
 
                     lti_is_dask = isinstance(es_lti_dict[child_df.ww.name], dd.Series)
                     lti_is_spark = is_instance(
-                        es_lti_dict[child_df.ww.name], ps, "Series"
+                        es_lti_dict[child_df.ww.name],
+                        ps,
+                        "Series",
                     )
 
                     if lti_is_dask or lti_is_spark:
@@ -1225,7 +1241,7 @@ class EntitySet(object):
                             {
                                 "last_time": es_lti_dict[child_df.ww.name],
                                 dataframe.ww.index: child_df[link_col],
-                            }
+                            },
                         )
 
                         # sort by time and keep only the most recent
@@ -1236,7 +1252,9 @@ class EntitySet(object):
                         )
 
                         lti_df.drop_duplicates(
-                            dataframe.ww.index, keep="last", inplace=True
+                            dataframe.ww.index,
+                            keep="last",
+                            inplace=True,
                         )
 
                         lti_df.set_index(dataframe.ww.index, inplace=True)
@@ -1249,22 +1267,23 @@ class EntitySet(object):
                         if lti_is_spark:
                             lti_df["last_time"] = ps.to_datetime(lti_df["last_time"])
                             lti_df["last_time_old"] = ps.to_datetime(
-                                lti_df["last_time_old"]
+                                lti_df["last_time_old"],
                             )
                             # TODO: Figure out a workaround for fillna and replace
                             lti_df = lti_df.max(axis=1)
                         else:
                             lti_df["last_time"] = lti_df["last_time"].astype(
-                                "datetime64[ns]"
+                                "datetime64[ns]",
                             )
                             lti_df["last_time_old"] = lti_df["last_time_old"].astype(
-                                "datetime64[ns]"
+                                "datetime64[ns]",
                             )
                             lti_df = lti_df.fillna(
-                                pd.to_datetime("1800-01-01 00:00")
+                                pd.to_datetime("1800-01-01 00:00"),
                             ).max(axis=1)
                             lti_df = lti_df.replace(
-                                pd.to_datetime("1800-01-01 00:00"), pd.NaT
+                                pd.to_datetime("1800-01-01 00:00"),
+                                pd.NaT,
                             )
 
                     es_lti_dict[dataframe.ww.name] = lti_df
@@ -1297,14 +1316,15 @@ class EntitySet(object):
                     else:
                         raise ValueError(
                             "Cannot add a last time index on DataFrame with an existing "
-                            f"'{LTI_COLUMN_NAME}' column. Please rename '{LTI_COLUMN_NAME}'."
+                            f"'{LTI_COLUMN_NAME}' column. Please rename '{LTI_COLUMN_NAME}'.",
                         )
 
                 # Add the new column to the DataFrame
                 if isinstance(df, dd.DataFrame):
                     new_df = df.merge(lti.reset_index(), on=df.ww.index)
                     new_df.ww.init(
-                        schema=df.ww.schema, logical_types={LTI_COLUMN_NAME: lti_ltype}
+                        schema=df.ww.schema,
+                        logical_types={LTI_COLUMN_NAME: lti_ltype},
                     )
 
                     new_idx = new_df[new_df.ww.index]
@@ -1314,7 +1334,8 @@ class EntitySet(object):
                 elif is_instance(df, ps, "DataFrame"):
                     new_df = df.merge(lti, left_on=df.ww.index, right_index=True)
                     new_df.ww.init(
-                        schema=df.ww.schema, logical_types={LTI_COLUMN_NAME: lti_ltype}
+                        schema=df.ww.schema,
+                        logical_types={LTI_COLUMN_NAME: lti_ltype},
                     )
 
                     dfs_to_update[df.ww.name] = new_df
@@ -1356,7 +1377,11 @@ class EntitySet(object):
     # #  Other ###############################################
     # ###########################################################################
     def add_interesting_values(
-        self, max_values=5, verbose=False, dataframe_name=None, values=None
+        self,
+        max_values=5,
+        verbose=False,
+        dataframe_name=None,
+        values=None,
     ):
         """Find or set interesting values for categorical columns, to be used to generate "where" clauses
 
@@ -1452,7 +1477,9 @@ class EntitySet(object):
 
         # Initialize a new directed graph
         graph = graphviz.Digraph(
-            self.id, format=format_, graph_attr={"splines": "ortho"}
+            self.id,
+            format=format_,
+            graph_attr={"splines": "ortho"},
         )
 
         # Draw dataframes
@@ -1489,7 +1516,9 @@ class EntitySet(object):
                 label = "%s -> %s" % (rel._parent_column_name, rel._child_column_name)
 
             graph.edge(
-                rel._child_dataframe_name, rel._parent_dataframe_name, xlabel=label
+                rel._child_dataframe_name,
+                rel._parent_dataframe_name,
+                xlabel=label,
             )
 
         if to_file:
@@ -1536,7 +1565,7 @@ class EntitySet(object):
                     else:
                         warnings.warn(
                             "Using training_window but last_time_index is "
-                            "not set for dataframe %s" % (dataframe_name)
+                            "not set for dataframe %s" % (dataframe_name),
                         )
 
                     df = df[mask]
@@ -1608,10 +1637,14 @@ class EntitySet(object):
         else:
             if is_instance(instance_vals, (dd, ps), "Series"):
                 df = dataframe.merge(
-                    instance_vals.to_frame(), how="inner", on=column_name
+                    instance_vals.to_frame(),
+                    how="inner",
+                    on=column_name,
                 )
             elif isinstance(instance_vals, pd.Series) and is_instance(
-                dataframe, ps, "DataFrame"
+                dataframe,
+                ps,
+                "DataFrame",
             ):
                 df = dataframe.merge(
                     ps.DataFrame({column_name: instance_vals}),
@@ -1633,10 +1666,12 @@ class EntitySet(object):
             #
             # Note: Woodwork stores categorical columns with a `string` dtype for Spark
             if dataframe.ww.columns[column_name].is_categorical and not is_instance(
-                df, ps, "DataFrame"
+                df,
+                ps,
+                "DataFrame",
             ):
                 categories = pd.api.types.CategoricalDtype(
-                    categories=dataframe[column_name].cat.categories
+                    categories=dataframe[column_name].cat.categories,
                 )
                 df[column_name] = df[column_name].astype(categories)
 
@@ -1689,23 +1724,25 @@ class EntitySet(object):
         if len(df.columns) != len(old_column_names):
             raise ValueError(
                 "New dataframe contains {} columns, expecting {}".format(
-                    len(df.columns), len(old_column_names)
-                )
+                    len(df.columns),
+                    len(old_column_names),
+                ),
             )
         for col_name in old_column_names:
             if col_name not in df.columns:
                 raise ValueError(
-                    "New dataframe is missing new {} column".format(col_name)
+                    "New dataframe is missing new {} column".format(col_name),
                 )
 
         if df.ww.schema is not None:
             warnings.warn(
                 "Woodwork typing information on new dataframe will be replaced "
-                f"with existing typing information from {dataframe_name}"
+                f"with existing typing information from {dataframe_name}",
             )
 
         df.ww.init(
-            schema=self[dataframe_name].ww._schema, already_sorted=already_sorted
+            schema=self[dataframe_name].ww._schema,
+            already_sorted=already_sorted,
         )
         # Make sure column ordering matches original ordering
         df = df.ww[old_column_names]
@@ -1719,7 +1756,8 @@ class EntitySet(object):
 
         df_metadata = self[dataframe_name].ww.metadata
         self.set_secondary_time_index(
-            dataframe_name, df_metadata.get("secondary_time_index")
+            dataframe_name,
+            df_metadata.get("secondary_time_index"),
         )
         if recalculate_last_time_indexes and last_time_index_column is not None:
             self.add_last_time_indexes(updated_dataframes=[dataframe_name])
@@ -1733,12 +1771,13 @@ class EntitySet(object):
 
     def _check_secondary_time_index(self, dataframe, secondary_time_index=None):
         secondary_time_index = secondary_time_index or dataframe.ww.metadata.get(
-            "secondary_time_index", {}
+            "secondary_time_index",
+            {},
         )
 
         if secondary_time_index and dataframe.ww.time_index is None:
             raise ValueError(
-                "Cannot set secondary time index on a DataFrame that has no primary time index."
+                "Cannot set secondary time index on a DataFrame that has no primary time index.",
             )
 
         for time_index, columns in secondary_time_index.items():
@@ -1798,11 +1837,13 @@ class EntitySet(object):
                 if ps and isinstance(series, ps.Series):
                     if len(series):
                         dataframe[column] = dataframe[column].apply(
-                            replace, args=(True,)
+                            replace,
+                            args=(True,),
                         )
                 elif isinstance(dataframe, dd.DataFrame):
                     dataframe[column] = dataframe[column].apply(
-                        replace, meta=(column, logical_type.primary_dtype)
+                        replace,
+                        meta=(column, logical_type.primary_dtype),
                     )
                 else:
                     dataframe[column] = dataframe[column].apply(replace)
@@ -1850,13 +1891,13 @@ def _get_or_create_index(index, make_index, df):
             (
                 "Using first column as index. "
                 "To change this, specify the index parameter"
-            )
+            ),
         )
         index = df.columns[0]
     elif make_index and index in df.columns:
         # Case 3: user wanted to make index but column already exists
         raise RuntimeError(
-            f"Cannot make index: column with name {index} already present"
+            f"Cannot make index: column with name {index} already present",
         )
     elif index not in df.columns:
         if not make_index:
@@ -1864,7 +1905,7 @@ def _get_or_create_index(index, make_index, df):
             # make_index.  Make new index column and warn
             warnings.warn(
                 "index {} not found in dataframe, creating new "
-                "integer column".format(index)
+                "integer column".format(index),
             )
         # Case 5: make_index with no errors or warnings
         # (Case 4 also uses this code path)
