@@ -113,14 +113,14 @@ class FeatureBase(object):
         """
         if self.number_output_features == 1:
             raise ValueError(
-                "The set_feature_names can only be used on features that have more than one output column."
+                "The set_feature_names can only be used on features that have more than one output column.",
             )
 
         num_new_names = len(names)
         if self.number_output_features != num_new_names:
             raise ValueError(
                 "Number of names provided must match the number of output features:"
-                f" {num_new_names} name(s) provided, {self.number_output_features} expected."
+                f" {num_new_names} name(s) provided, {self.number_output_features} expected.",
             )
 
         if len(set(names)) != num_new_names:
@@ -273,43 +273,57 @@ class FeatureBase(object):
     def __eq__(self, other):
         """Compares to other by equality"""
         return self._handle_binary_comparision(
-            other, primitives.Equal, primitives.EqualScalar
+            other,
+            primitives.Equal,
+            primitives.EqualScalar,
         )
 
     def __ne__(self, other):
         """Compares to other by non-equality"""
         return self._handle_binary_comparision(
-            other, primitives.NotEqual, primitives.NotEqualScalar
+            other,
+            primitives.NotEqual,
+            primitives.NotEqualScalar,
         )
 
     def __gt__(self, other):
         """Compares if greater than other"""
         return self._handle_binary_comparision(
-            other, primitives.GreaterThan, primitives.GreaterThanScalar
+            other,
+            primitives.GreaterThan,
+            primitives.GreaterThanScalar,
         )
 
     def __ge__(self, other):
         """Compares if greater than or equal to other"""
         return self._handle_binary_comparision(
-            other, primitives.GreaterThanEqualTo, primitives.GreaterThanEqualToScalar
+            other,
+            primitives.GreaterThanEqualTo,
+            primitives.GreaterThanEqualToScalar,
         )
 
     def __lt__(self, other):
         """Compares if less than other"""
         return self._handle_binary_comparision(
-            other, primitives.LessThan, primitives.LessThanScalar
+            other,
+            primitives.LessThan,
+            primitives.LessThanScalar,
         )
 
     def __le__(self, other):
         """Compares if less than or equal to other"""
         return self._handle_binary_comparision(
-            other, primitives.LessThanEqualTo, primitives.LessThanEqualToScalar
+            other,
+            primitives.LessThanEqualTo,
+            primitives.LessThanEqualToScalar,
         )
 
     def __add__(self, other):
         """Add other"""
         return self._handle_binary_comparision(
-            other, primitives.AddNumeric, primitives.AddNumericScalar
+            other,
+            primitives.AddNumeric,
+            primitives.AddNumericScalar,
         )
 
     def __radd__(self, other):
@@ -318,7 +332,9 @@ class FeatureBase(object):
     def __sub__(self, other):
         """Subtract other"""
         return self._handle_binary_comparision(
-            other, primitives.SubtractNumeric, primitives.SubtractNumericScalar
+            other,
+            primitives.SubtractNumeric,
+            primitives.SubtractNumericScalar,
         )
 
     def __rsub__(self, other):
@@ -327,7 +343,9 @@ class FeatureBase(object):
     def __div__(self, other):
         """Divide by other"""
         return self._handle_binary_comparision(
-            other, primitives.DivideNumeric, primitives.DivideNumericScalar
+            other,
+            primitives.DivideNumeric,
+            primitives.DivideNumericScalar,
         )
 
     def __truediv__(self, other):
@@ -346,24 +364,29 @@ class FeatureBase(object):
                 [
                     isinstance(f.column_schema.logical_type, (Boolean, BooleanNullable))
                     for f in (self, other)
-                ]
+                ],
             ):
                 return Feature([self, other], primitive=primitives.MultiplyBoolean)
             if (
                 "numeric" in self.column_schema.semantic_tags
                 and isinstance(
-                    other.column_schema.logical_type, (Boolean, BooleanNullable)
+                    other.column_schema.logical_type,
+                    (Boolean, BooleanNullable),
                 )
                 or "numeric" in other.column_schema.semantic_tags
                 and isinstance(
-                    self.column_schema.logical_type, (Boolean, BooleanNullable)
+                    self.column_schema.logical_type,
+                    (Boolean, BooleanNullable),
                 )
             ):
                 return Feature(
-                    [self, other], primitive=primitives.MultiplyNumericBoolean
+                    [self, other],
+                    primitive=primitives.MultiplyNumericBoolean,
                 )
         return self._handle_binary_comparision(
-            other, primitives.MultiplyNumeric, primitives.MultiplyNumericScalar
+            other,
+            primitives.MultiplyNumeric,
+            primitives.MultiplyNumericScalar,
         )
 
     def __rmul__(self, other):
@@ -372,7 +395,9 @@ class FeatureBase(object):
     def __mod__(self, other):
         """Take modulus of other"""
         return self._handle_binary_comparision(
-            other, primitives.ModuloNumeric, primitives.ModuloNumericScalar
+            other,
+            primitives.ModuloNumeric,
+            primitives.ModuloNumericScalar,
         )
 
     def __rmod__(self, other):
@@ -413,7 +438,8 @@ class FeatureBase(object):
 
     def isin(self, list_of_output):
         return Feature(
-            [self], primitive=primitives.IsIn(list_of_outputs=list_of_output)
+            [self],
+            primitive=primitives.IsIn(list_of_outputs=list_of_output),
         )
 
     def is_null(self):
@@ -484,12 +510,18 @@ class DirectFeature(FeatureBase):
     return_type = None
 
     def __init__(
-        self, base_feature, child_dataframe_name, relationship=None, name=None
+        self,
+        base_feature,
+        child_dataframe_name,
+        relationship=None,
+        name=None,
     ):
         base_feature = _validate_base_features(base_feature)[0]
         self.parent_dataframe_name = base_feature.dataframe_name
         relationship = self._handle_relationship(
-            base_feature.entityset, child_dataframe_name, relationship
+            base_feature.entityset,
+            child_dataframe_name,
+            relationship,
         )
         child_dataframe = base_feature.entityset[child_dataframe_name]
         super(DirectFeature, self).__init__(
@@ -513,7 +545,7 @@ class DirectFeature(FeatureBase):
             ), "Base feature must be defined on the relationship parent dataframe"
         else:
             child_relationships = entityset.get_forward_relationships(
-                child_dataframe.ww.name
+                child_dataframe.ww.name,
             )
             possible_relationships = (
                 r
@@ -525,7 +557,7 @@ class DirectFeature(FeatureBase):
             if not relationship:
                 raise RuntimeError(
                     'No relationship from "%s" to "%s" found.'
-                    % (child_dataframe.ww.name, self.parent_dataframe_name)
+                    % (child_dataframe.ww.name, self.parent_dataframe_name),
                 )
 
             # Check for another path.
@@ -542,7 +574,8 @@ class DirectFeature(FeatureBase):
     def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         base_feature = dependencies[arguments["base_feature"]]
         relationship = Relationship.from_dictionary(
-            arguments["relationship"], entityset
+            arguments["relationship"],
+            entityset,
         )
         child_dataframe_name = relationship.child_dataframe.ww.name
         return cls(
@@ -564,7 +597,9 @@ class DirectFeature(FeatureBase):
         """Return copy of feature"""
         _is_forward, relationship = self.relationship_path[0]
         return DirectFeature(
-            self.base_features[0], self.dataframe_name, relationship=relationship
+            self.base_features[0],
+            self.dataframe_name,
+            relationship=relationship,
         )
 
     @property
@@ -620,7 +655,9 @@ class AggregationFeature(FeatureBase):
         self.child_dataframe_name = base_features[0].dataframe_name
         entityset = base_features[0].entityset
         relationship_path, self._path_is_unique = self._handle_relationship_path(
-            entityset, parent_dataframe_name, relationship_path
+            entityset,
+            parent_dataframe_name,
+            relationship_path,
         )
 
         self.parent_dataframe_name = parent_dataframe_name
@@ -628,7 +665,7 @@ class AggregationFeature(FeatureBase):
         if where is not None:
             self.where = _validate_base_features(where)[0]
             msg = "Where feature must be defined on child dataframe {}".format(
-                self.child_dataframe_name
+                self.child_dataframe_name,
             )
             assert self.where.dataframe_name == self.child_dataframe_name, msg
 
@@ -655,7 +692,10 @@ class AggregationFeature(FeatureBase):
         )
 
     def _handle_relationship_path(
-        self, entityset, parent_dataframe_name, relationship_path
+        self,
+        entityset,
+        parent_dataframe_name,
+        relationship_path,
     ):
         parent_dataframe = entityset[parent_dataframe_name]
         child_dataframe = entityset[self.child_dataframe_name]
@@ -677,18 +717,20 @@ class AggregationFeature(FeatureBase):
             ), "Base feature must be defined on the dataframe at the end of relationship_path"
 
             path_is_unique = entityset.has_unique_forward_path(
-                child_dataframe.ww.name, parent_dataframe.ww.name
+                child_dataframe.ww.name,
+                parent_dataframe.ww.name,
             )
         else:
             paths = entityset.find_backward_paths(
-                parent_dataframe.ww.name, child_dataframe.ww.name
+                parent_dataframe.ww.name,
+                child_dataframe.ww.name,
             )
             first_path = next(paths, None)
 
             if not first_path:
                 raise RuntimeError(
                     'No backward path from "%s" to "%s" found.'
-                    % (parent_dataframe.ww.name, child_dataframe.ww.name)
+                    % (parent_dataframe.ww.name, child_dataframe.ww.name),
                 )
             # Check for another path.
             elif next(paths, None):
@@ -715,7 +757,7 @@ class AggregationFeature(FeatureBase):
 
         use_previous_data = arguments["use_previous"]
         use_previous = use_previous_data and Timedelta.from_dictionary(
-            use_previous_data
+            use_previous_data,
         )
 
         where_name = arguments["where"]
@@ -815,7 +857,9 @@ class TransformFeature(FeatureBase):
     def from_dictionary(cls, arguments, entityset, dependencies, primitive):
         base_features = [dependencies[name] for name in arguments["base_features"]]
         feat = cls(
-            base_features=base_features, primitive=primitive, name=arguments["name"]
+            base_features=base_features,
+            primitive=primitive,
+            name=arguments["name"],
         )
         feat._names = arguments.get("feature_names")
         return feat
@@ -825,12 +869,12 @@ class TransformFeature(FeatureBase):
 
     def generate_name(self):
         return self.primitive.generate_name(
-            base_feature_names=[bf.get_name() for bf in self.base_features]
+            base_feature_names=[bf.get_name() for bf in self.base_features],
         )
 
     def generate_names(self):
         return self.primitive.generate_names(
-            base_feature_names=[bf.get_name() for bf in self.base_features]
+            base_feature_names=[bf.get_name() for bf in self.base_features],
         )
 
     def get_arguments(self):
@@ -857,7 +901,9 @@ class GroupByTransformFeature(TransformFeature):
         base_features.append(groupby)
 
         super(GroupByTransformFeature, self).__init__(
-            base_features=base_features, primitive=primitive, name=name
+            base_features=base_features,
+            primitive=primitive,
+            name=name,
         )
 
     @classmethod
@@ -877,7 +923,9 @@ class GroupByTransformFeature(TransformFeature):
         # the groupby feature is appended to base_features in the __init__
         # so here we separate them again
         return GroupByTransformFeature(
-            self.base_features[:-1], self.primitive, self.groupby
+            self.base_features[:-1],
+            self.primitive,
+            self.groupby,
         )
 
     def generate_name(self):
@@ -933,7 +981,8 @@ class Feature(object):
             return DirectFeature(base, dataframe_name)
         elif primitive is not None and parent_dataframe_name is not None:
             assert isinstance(primitive, AggregationPrimitive) or issubclass(
-                primitive, AggregationPrimitive
+                primitive,
+                AggregationPrimitive,
             )
             return AggregationFeature(
                 base,
@@ -944,11 +993,14 @@ class Feature(object):
             )
         elif primitive is not None:
             assert isinstance(primitive, TransformPrimitive) or issubclass(
-                primitive, TransformPrimitive
+                primitive,
+                TransformPrimitive,
             )
             if groupby is not None:
                 return GroupByTransformFeature(
-                    base, primitive=primitive, groupby=groupby
+                    base,
+                    primitive=primitive,
+                    groupby=groupby,
                 )
             return TransformFeature(base, primitive=primitive)
 
@@ -967,7 +1019,7 @@ class FeatureOutputSlice(FeatureBase):
         msg = "cannot access slice from single output feature"
         assert self.num_output_parent > 1, msg
         msg = "cannot access column that is not between 0 and " + str(
-            self.num_output_parent - 1
+            self.num_output_parent - 1,
         )
         assert n < self.num_output_parent, msg
 
