@@ -1,6 +1,6 @@
 # flake8: noqa
-from .standard import *
-from .utils import (
+from featuretools.primitives.standard import *
+from featuretools.primitives.utils import (
     get_aggregation_primitives,
     get_default_aggregation_primitives,
     get_default_transform_primitives,
