@@ -140,7 +140,7 @@ def is_instance(obj, modules, classnames):
 
 
 def camel_and_title_to_snake(name):
-    name = re.sub(r"(\d+)", r"_\1", name).strip("_")
+    name = re.sub(r"([^_\d]+)(\d+)", r"\1_\2", name)
     name = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", name)
     return re.sub("([a-z0-9])([A-Z])", r"\1_\2", name).lower()
 
